<?php
/**
*
* @package phpBB3
* @version $Id: common.php 8760 2008-08-15 19:46:51Z aptx $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
* Minimum Requirement: PHP 4.3.3
*/

/**
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

$starttime = explode(' ', microtime());
$starttime = $starttime[1] + $starttime[0];

// Report all errors, except notices
error_reporting(E_ALL ^ E_NOTICE);

/*
* Remove variables created by register_globals from the global scope
* Thanks to Matt Kavanagh
*/
function deregister_globals()
{
	$not_unset = array(
		'GLOBALS'	=> true,
		'_GET'		=> true,
		'_POST'		=> true,
		'_COOKIE'	=> true,
		'_REQUEST'	=> true,
		'_SERVER'	=> true,
		'_SESSION'	=> true,
		'_ENV'		=> true,
		'_FILES'	=> true,
		'phpEx'		=> true,
		'phpbb_root_path'	=> true
	);

	// Not only will array_merge and array_keys give a warning if
	// a parameter is not an array, array_merge will actually fail.
	// So we check if _SESSION has been initialised.
	if (!isset($_SESSION) || !is_array($_SESSION))
	{
		$_SESSION = array();
	}

	// Merge all into one extremely huge array; unset this later
	$input = array_merge(
		array_keys($_GET),
		array_keys($_POST),
		array_keys($_COOKIE),
		array_keys($_SERVER),
		array_keys($_SESSION),
		array_keys($_ENV),
		array_keys($_FILES)
	);

	foreach ($input as $varname)
	{
		if (isset($not_unset[$varname]))
		{
			// Hacking attempt. No point in continuing unless it's a COOKIE
			if ($varname !== 'GLOBALS' || isset($_GET['GLOBALS']) || isset($_POST['GLOBALS']) || isset($_SERVER['GLOBALS']) || isset($_SESSION['GLOBALS']) || isset($_ENV['GLOBALS']) || isset($_FILES['GLOBALS']))
			{
				exit;
			}
			else
			{
				$cookie = &$_COOKIE;
				while (isset($cookie['GLOBALS']))
				{
					foreach ($cookie['GLOBALS'] as $registered_var => $value)
					{
						if (!isset($not_unset[$registered_var]))
						{
							unset($GLOBALS[$registered_var]);
						}
					}
					$cookie = &$cookie['GLOBALS'];
				}
			}
		}

		unset($GLOBALS[$varname]);
	}

	unset($input);
}

// If we are on PHP >= 6.0.0 we do not need some code
if (version_compare(PHP_VERSION, '6.0.0-dev', '>='))
{
	/**
	* @ignore
	*/
	define('STRIP', false);
}
else
{
	@set_magic_quotes_runtime(0);

	// Be paranoid with passed vars
	if (@ini_get('register_globals') == '1' || strtolower(@ini_get('register_globals')) == 'on' || !function_exists('ini_get'))
	{
		deregister_globals();
	}

	define('STRIP', (get_magic_quotes_gpc()) ? true : false);
}

if (defined('IN_CRON'))
{
	$phpbb_root_path = dirname(__FILE__) . DIRECTORY_SEPARATOR;
}

if (!file_exists($phpbb_root_path . 'config.' . $phpEx))
{
	die("<p>The config.$phpEx file could not be found.</p><p><a href=\"{$phpbb_root_path}install/index.$phpEx\">Click here to install phpBB</a></p>");
}

require($phpbb_root_path . 'config.' . $phpEx);

if (!defined('PHPBB_INSTALLED'))
{
	// Redirect the user to the installer
	// We have to generate a full HTTP/1.1 header here since we can't guarantee to have any of the information
	// available as used by the redirect function
	$server_name = (!empty($_SERVER['HTTP_HOST'])) ? strtolower($_SERVER['HTTP_HOST']) : ((!empty($_SERVER['SERVER_NAME'])) ? $_SERVER['SERVER_NAME'] : getenv('SERVER_NAME'));
	$server_port = (!empty($_SERVER['SERVER_PORT'])) ? (int) $_SERVER['SERVER_PORT'] : (int) getenv('SERVER_PORT');
	$secure = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') ? 1 : 0;

	$script_name = (!empty($_SERVER['PHP_SELF'])) ? $_SERVER['PHP_SELF'] : getenv('PHP_SELF');
	if (!$script_name)
	{
		$script_name = (!empty($_SERVER['REQUEST_URI'])) ? $_SERVER['REQUEST_URI'] : getenv('REQUEST_URI');
	}

	// Replace any number of consecutive backslashes and/or slashes with a single slash
	// (could happen on some proxy setups and/or Windows servers)
	$script_path = trim(dirname($script_name)) . '/modules/' . basename(dirname(__FILE__)) . '/install/index.' . $phpEx;
	
	$script_path = preg_replace('#[\\\\/]{2,}#', '/', $script_path);

	$url = (($secure) ? 'https://' : 'http://') . $server_name;

	if ($server_port && (($secure && $server_port <> 443) || (!$secure && $server_port <> 80)))
	{
		// HTTP HOST can carry a port number...
		if (strpos($server_name, ':') === false)
		{
			$url .= ':' . $server_port;
		}
	}

	$url .= $script_path;
	header('Location: ' . $url);
	exit;
}

if (defined('DEBUG_EXTRA'))
{
	$base_memory_usage = 0;
	if (function_exists('memory_get_usage'))
	{
		$base_memory_usage = memory_get_usage();
	}
}

// Load Extensions
if (!empty($load_extensions))
{
	$load_extensions = explode(',', $load_extensions);

	foreach ($load_extensions as $extension)
	{
		@dl(trim($extension));
	}
}

// Include files
require($phpbb_root_path . 'includes/acm/acm_' . $acm_type . '.' . $phpEx);
require($phpbb_root_path . 'includes/cache.' . $phpEx);
require($phpbb_root_path . 'includes/template.' . $phpEx);
require($phpbb_root_path . 'includes/session.' . $phpEx);
require($phpbb_root_path . 'includes/auth.' . $phpEx);

require($phpbb_root_path . 'includes/functions.' . $phpEx);
require($phpbb_root_path . 'includes/functions_content.' . $phpEx);

require($phpbb_root_path . 'includes/constants.' . $phpEx);
require($phpbb_root_path . 'includes/db/' . $dbms . '.' . $phpEx);
require($phpbb_root_path . 'includes/utf/utf_tools.' . $phpEx);

// Set PHP error handler to ours
set_error_handler(defined('PHPBB_MSG_HANDLER') ? PHPBB_MSG_HANDLER : 'msg_handler');

// Instantiate some basic classes
$phpBB3user	= new user();

$auth		= new auth();
$template	= new template();
$cache		= new cache();

$phpBB3db	= new $sql_db();

// Connect to DB
$phpBB3db->sql_connect($dbhost, $dbuser, $dbpasswd, $dbname, $dbport, false, defined('PHPBB_DB_NEW_LINK') ? PHPBB_DB_NEW_LINK : false);

// We do not need this any longer, unset for safety purposes
unset($dbpasswd);

// Grab global variables, re-cache if necessary
$config = $cache->obtain_config();

// Add own hook handler
require($phpbb_root_path . 'includes/hooks/index.' . $phpEx);
$phpbb_hook = new phpbb_hook(array('exit_handler', 'phpbb_user_session_handler', 'append_sid', array('template', 'display')));

foreach ($cache->obtain_hooks() as $hook)
{
	@include($phpbb_root_path . 'includes/hooks/' . $hook . '.' . $phpEx);
}

$module_name = basename(dirname(__FILE__));
@require_once($phpbb_root_path . '../../config.php');
// $row = $phpBB3db->sql_fetchrow($phpBB3db->sql_query("SELECT `Default_Theme`, `overwrite_theme`, `language`, `multilingual` FROM ".$prefix."_config"));
$row = $phpBB3db->sql_fetchrow($phpBB3db->sql_query("SELECT `Default_Theme`, `language`, `multilingual` FROM ".$prefix."_config"));
$nukeDefaultTheme = $row['Default_Theme'];
// $nukeOverwriteTheme = intval($row['overwrite_theme']);
$nukeLanguage = $row['language'];

$nukeMultilingual = intval($row['multilingual']);

if (isset($_COOKIE['user']))
{
	// docode
	$nukeUserCookie = base64_decode($_COOKIE['user']);
	$nukeUserCookie = explode(":", $nukeUserCookie);
	$nukeUserID = $nukeUserCookie[0];
	$nukeUserName = $nukeUserCookie[1];
	$nukeUserTheme = $nukeUserCookie[9];
};

$http_language_code=array();

$http_language_code['afrikaans']	= 'af'; //
$http_language_code['arabic']		= 'ar'; //
$http_language_code['belarusian']	= 'be'; //
$http_language_code['bulgarian']	= 'bg'; //  
$http_language_code['catalan']		= 'ca'; //  
$http_language_code['czech']		= 'cs'; //  
$http_language_code['danish']		= 'da'; //
$http_language_code['german']		= 'de'; // (Standard)
$http_language_code['greek']		= 'el'; //  
$http_language_code['english']		= 'en'; //  
$http_language_code['spanish']		= 'es'; // (Argentina)
$http_language_code['estonian']		= 'et'; //  
$http_language_code['basque']		= 'eu'; //
$http_language_code['farsi']		= 'fa'; //  
$http_language_code['finnish']		= 'fi'; //
$http_language_code['faeroese']		= 'fo'; //
$http_language_code['french']		= 'fr'; // (Standard)  
$http_language_code['french']		= 'fr'; // (Belgium)
$http_language_code['gaelic']		= 'gd'; // (Scotland)
$http_language_code['hebrew']		= 'he'; //
$http_language_code['hindi']		= 'hi'; //  
$http_language_code['croatian']		= 'hr'; //
$http_language_code['hungarian']	= 'hu'; //
$http_language_code['indonesian']	= 'id'; //
$http_language_code['italian']		= 'it'; // (Standard)  
$http_language_code['icelandic']	= 'is'; //  
$http_language_code['korean']		= 'kr';		// korean
$http_language_code['japanese']		= 'ja'; //  
$http_language_code['yiddish']		= 'ji'; //
$http_language_code['latvian']		= 'lv'; //
$http_language_code['lithuanian']	= 'lt'; //  
$http_language_code['macedonian']	= 'mk'; // (FYROM)
$http_language_code['malaysian']	= 'ms'; //  
$http_language_code['maltese']		= 'mt';	//
$http_language_code['dutch']		= 'nl'; // (Standard)  
$http_language_code['norwegian']	= 'no'; // (Nynorsk)
$http_language_code['polish']		= 'pl'; //  
$http_language_code['portuguese']	= 'pt'; // (Portugal)  
$http_language_code['rhaeto-Romanic'] = 'rm'; //
$http_language_code['romanian']		= 'ro'; //  
$http_language_code['russian']		= 'ru';; //  
$http_language_code['sorbian']		= 'sb'; //
$http_language_code['slovak']		= 'sk'; //
$http_language_code['slovenian']	= 'sl'; //  
$http_language_code['albanian']		= 'sq'; //
$http_language_code['serbian']		= 'sr'; // (Latin)  
$http_language_code['sutu']			= 'sx'; //
$http_language_code['sami']			= 'sz'; // (Lappish)  
$http_language_code['swedish']		= 'sv'; //  
$http_language_code['swedish']		= 'sv-fi'; // (Finland)
$http_language_code['thai']			= 'th'; //  
$http_language_code['tswana']		= 'tn'; //  
$http_language_code['tsonga']		= 'ts'; //
$http_language_code['turkish']		= 'tr'; //
$http_language_code['urdu']			= 'ur'; //
$http_language_code['vietnamese']	= 'vi'; //
$http_language_code['ukrainian']	= 'uk'; //  
$http_language_code['venda']		= 've'; //  
$http_language_code['xhosa']		= 'xh'; //  
$http_language_code['chinese']		= 'zh'; // (Chinese Standard)
$http_language_code['zulu']			= 'zu'; //

$nukeUserLanguage = "";
if (isset($_COOKIE['lang']))
{
	$nukeUserLanguage = $_COOKIE['lang'];

	if ($multilingual)
	{
		$phpBB3LanguageName = $http_language_code[$nukeUserLanguage];
	}
	else
	{
		$phpBB3LanguageName = $http_language_code[$nukeLanguage];
	};

	unset($http_language_code);
}
else
{
	$phpBB3LanguageName = $http_language_code[$nukeLanguage];
};

?>
